@@ -18,19 +18,19 @@ __docformat__ = 'reStrructuredText'
 
 
 class revealjs(nodes.General, nodes.Element):
-    pass
+    """ node for revealjs """
 
 
 class rv_code(nodes.General, nodes.Element):
-    pass
+    """ node for revealjs code section """
 
 
 class rv_small(nodes.General, nodes.Element):
-    pass
+    """ node for revealjs small text section """
 
 
 class rv_note(nodes.General, nodes.Element):
-    pass
+    """ node for revealjs presentation note """
 
 
 def heading(argument):
@@ -53,9 +53,10 @@ class RevealjsDirective(Directive):
         'title-heading': heading,
         'subtitle': directives.unchanged,
         'subtitle-heading': directives.unchanged,
+        'data-autoslide': directives.unchanged,
         'data-markdown': directives.unchanged,
-        'data_state': directives.unchanged,
         'data-transition': directives.unchanged,
+        'data-transition-speed': directives.unchanged,
         'data-background': directives.unchanged,
         'data-background-repeat': directives.unchanged,
         'data-background-size': directives.unchanged,
@@ -63,7 +64,10 @@ class RevealjsDirective(Directive):
         'data-state': directives.unchanged,
         'data-separator': directives.unchanged,
         'data-vertical': directives.unchanged,
+        'data-notes': directives.unchanged,
+        'data-charset': directives.unchanged,
     }
+
     node_class = revealjs
 
     def run(self):
@@ -82,16 +86,15 @@ class RevealjsDirective(Directive):
         if self.arguments:
             node['title'] = " ".join(self.arguments)
 
-        if 'class' in self.options:
-            node['classes'].append(self.options['class'])
-
         node['noheading'] = ('noheading' in self.options)
 
         options_list = (
             'id',
             'title-heading',
             'subtitle-heading',
+            'data-autoslide',
             'data-transition',
+            'data-transition-speed',
             'data-background',
             'data-background-repeat',
             'data-background-size',
@@ -100,6 +103,8 @@ class RevealjsDirective(Directive):
             'data-markdown',
             'data-separator',
             'data-vertical',
+            'data-notes',
+            'data-charset',
         )
         for option in options_list:
             if option in self.options:
@@ -130,8 +135,6 @@ class RvSmallDirective(Directive):
         node = self.node_class(text, **self.options)
         self.add_name(node)
         self.state.nested_parse(self.content, self.content_offset, node)
-        if 'class' in self.options:
-            node['classes'].append(self.options['class'])
         return [node]
 
 
@@ -151,15 +154,12 @@ class RvNoteDirective(Directive):
 
     def run(self):
         """ build rv_note node """
-
         set_classes(self.options)
         self.assert_has_content()
         text = '\n'.join(self.content)
         node = self.node_class(text, **self.options)
         self.add_name(node)
         self.state.nested_parse(self.content, self.content_offset, node)
-        if 'class' in self.options:
-            node['classes'].append(self.options['class'])
         return [node]
 
 
@@ -172,13 +172,11 @@ class RvCodeDirective(Directive):
     required_arguments = 0
     optional_arguments = 0
     final_argument_whitespace = False
-    option_spec = {
-    }
+    option_spec = {}
     node_class = rv_code
 
     def run(self):
         """ build rv_code node """
-
         set_classes(self.options)
         self.assert_has_content()
         node = self.node_class('\n'.join(self.content), **self.options)
@@ -189,13 +187,15 @@ def visit_revealjs(self, node):
     """ build start tag for revealjs """
     section_attr = {}
     markdown_headings = {"h1": "#", "h2": "##", "h3": "###",
-                       "h4": "####", "h5": "#####", "h6": "######"}
+                         "h4": "####", "h5": "#####", "h6": "######"}
 
     if node.get("id"):
         section_attr.update({"ids": [node.get("id")]})
 
     attr_list = (
+        'data-autoslide',
         'data-transition',
+        'data-transition-speed',
         'data-background',
         'data-background-repeat',
         'data-background-size',
@@ -204,6 +204,8 @@ def visit_revealjs(self, node):
         'data-markdown',
         'data-separator',
         'data-vertical',
+        'data-notes',
+        'data-charset',
     )
     for attr in attr_list:
         if node.get(attr) is not None:
@@ -228,13 +230,12 @@ def visit_revealjs(self, node):
 
         subtitle_text = None
         if subtitle:
-            subtitle_text = title_base  % dict(
+            subtitle_text = title_base % dict(
                 heading=markdown_headings.get(subtitle_heading),
                 title=subtitle
             )
     else:
         title_base = compat.text("<%(heading)s>%(title)s</%(heading)s>\n")
-
         title_text = None
         if title:
             title_text = title_base % dict(
